@@ -3,11 +3,11 @@ from . import modulenames
 name = "yeonji"
 author = {
 	"name":"Johannes Krattenmacher",
-	"email":"python@krateng.dev",
+	"email":"yeonji@dev.krateng.ch",
 	"github":"krateng"
 }
 desc = "Collection of command line tools"
-version = 0,6,3
+version = 0,6,4
 
 
 requires = [
